@@ -14,7 +14,7 @@
 
 from pythonic_fp.containers.functional_tuple import FTuple
 from pythonic_fp.fptools.maybe import MayBe
-from pythonic_fp.containers.queues.de import DEQueue, de_queue
+from pythonic_fp.queues.de import DEQueue, de_queue
 
 
 class Test_MB_sequence:
